@@ -29,8 +29,8 @@
 SEXP polyn_eval(SEXP coef, SEXP x)
 {
  SEXP result;
- int n = LENGTH(x), i, j,
-     m = LENGTH(coef);
+ R_xlen_t n = XLENGTH(x);
+ int m = LENGTH(coef);
  // deal with integer or numeric -- NULL cannot (yet?) be coerced
  if(isNull(x)) { result = allocVector(REALSXP, 0); return result; }
  if(!isNull(coef))
@@ -39,12 +39,12 @@ SEXP polyn_eval(SEXP coef, SEXP x)
  PROTECT(x = isReal(x) ? Rf_duplicate(x) : coerceVector(x, REALSXP));
  PROTECT(result = Rf_duplicate(x));
  double *cf = REAL(coef), *xx = REAL(x), *res = REAL(result);
- for(i = 0; i < n; i++) {
+ for(R_xlen_t i = 0; i < n; i++) {
    double r, xi = xx[i];
    if(m == 0) {
       r = 0.;
    } else {
-      j = m-1;
+      int j = m-1;
       r = cf[j];
       for (j--; j >= 0; j--)
           r = cf[j] + r * xi;
